summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/objects/object_imp.h')
-rw-r--r--kig/objects/object_imp.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kig/objects/object_imp.h b/kig/objects/object_imp.h
index 46166858..ddf0eb46 100644
--- a/kig/objects/object_imp.h
+++ b/kig/objects/object_imp.h
@@ -87,7 +87,7 @@ typedef unsigned int uint;
*/
class ObjectImpType
{
- const ObjectImpType* mtqparent;
+ const ObjectImpType* mparent;
const char* minternalname;
const char* mtranslatedname;
const char* mselectstatement;
@@ -126,12 +126,12 @@ public:
* hideastatement is a translatable string like "Hide a Segment"
*
* All translatable strings should have
* I18N_NOOP around them ! @param tqparent is the ObjectImpType of
* your tqparent ObjectImp type. Never give 0 as tqparent, except for
* the top ObjectImp ObjectImpType..
*/
ObjectImpType(
- const ObjectImpType* tqparent, const char* internalname,
+ const ObjectImpType* parent, const char* internalname,
const char* translatedname,
const char* selectstatement,
const char* selectnamestatement,
@@ -126,12 +126,12 @@ public:
*
* All translatable strings should have
- * I18N_NOOP around them ! @param tqparent is the ObjectImpType of
- * your tqparent ObjectImp type. Never give 0 as tqparent, except for
+ * I18N_NOOP around them ! @param parent is the ObjectImpType of
+ * your parent ObjectImp type. Never give 0 as parent, except for
* the top ObjectImp ObjectImpType..
*/